@@ -24,7 +24,7 @@ import sys
 distname = "nazca"
 modname = "nazca"
 
-numversion = (0, 9, 6)
+numversion = (2, 0, 0)
 version = ".".join([str(num) for num in numversion])
 
 license = "LGPL"  # 2.1 or later
@@ -35,6 +35,8 @@ author_email = "contact@logilab.fr"
 
 classifiers = [
     "Programming Language :: Python",
+    "Programming Language :: Python :: 3",
+    "Programming Language :: Python :: 3 :: Only",
     "Topic :: Scientific/Engineering :: Information Analysis",
     "Topic :: Software Development :: Libraries :: Python Modules",
     "Topic :: Text Processing",
@@ -43,7 +45,6 @@ classifiers = [
 __depends__ = {
     "python-dateutil": None,
     "lxml": None,
-    "six": None,
     "numpy": None,
     "scipy": None,
     "scikit-learn": None,
