@@ -29,9 +29,6 @@ Additional information:
 """
 from functools import partial
 
-from six import iteritems, itervalues
-from six.moves import xrange
-
 from scipy.spatial import KDTree
 
 from nazca.utils.minhashing import Minlsh
@@ -236,7 +233,7 @@ class KeyBlocking(BaseBlocking):
                           and containts the indexes of the record in the
                           corresponding dataset.
         """
-        for key, block1 in iteritems(self.reference_index):
+        for key, block1 in self.reference_index.items():
             block2 = self.target_index.get(key)
             if block1 and block2:
                 yield (block1, block2)
@@ -292,7 +289,7 @@ class NGramBlocking(BaseBlocking):
     def _iter_dict(self, ref_cur_dict, target_cur_dict):
         """ Iterative function used to create blocks from dicts
         """
-        for key, sub_dict in iteritems(ref_cur_dict):
+        for key, sub_dict in ref_cur_dict.items():
             if key in target_cur_dict:
                 if isinstance(sub_dict, dict):
                     # There is another dict layer
@@ -427,7 +424,7 @@ class MergeBlocking(BaseBlocking):
             ):
                 # Change current score
                 merged_dataset_dict[record[attr_index]] = (ind, record, score)
-        return [(ind, r[0]) for ind, r, score in itervalues(merged_dataset_dict)]
+        return [(ind, r[0]) for ind, r, score in merged_dataset_dict.values()]
 
     def _iter_blocks(self):
         """ Iterator over the different possible blocks.
@@ -466,7 +463,7 @@ class KmeansBlocking(BaseBlocking):
         """
         # If an element is None (missing), use instead the identity element.
         # The identity element is defined as the 0-vector
-        idelement = tuple([0 for _ in xrange(len(refset[0][self.ref_attr_index]))])
+        idelement = tuple([0,] * len(refset[0][self.ref_attr_index]))
         # We assume here that there are at least 2 elements in the refset
         n_clusters = self.n_clusters or (len(refset) // 10 or len(refset) // 2)
         try:
@@ -492,7 +489,7 @@ class KmeansBlocking(BaseBlocking):
                           corresponding dataset.
         """
         n_clusters = self.kmeans.n_clusters if hasattr(self.kmeans, "n_clusters") else self.kmeans.k
-        neighbours = [[[], []] for _ in xrange(n_clusters)]
+        neighbours = [[[], []] for _ in range(n_clusters)]
         for ind, li in enumerate(self.predicted):
             neighbours[li][1].append(self.targetids[ind])
         for ind, li in enumerate(self.kmeans.labels_):
@@ -553,7 +550,7 @@ class KdTreeBlocking(BaseBlocking):
         """
         extraneighbours = self.reftree.query_ball_tree(self.targettree, self.threshold)
         neighbours = []
-        for ind in xrange(self.nb_elements):
+        for ind in range(self.nb_elements):
             if not extraneighbours[ind]:
                 continue
             _ref = [
@@ -580,14 +577,41 @@ class MinHashingBlocking(BaseBlocking):
     """ A blocking technique based on MinHashing
     """
 
-    def __init__(self, ref_attr_index, target_attr_index, threshold=0.1, kwordsgram=1, siglen=200):
+    # This is the random seed to be used to computed the hash functions, when
+    # the user wants repeatable results.
+    FIXED_RANDOM_SEED = "4; chosen by fair dice roll. Guaranteed to be random."
+
+    def __init__(
+        self,
+        ref_attr_index,
+        target_attr_index,
+        threshold=0.1,
+        kwordsgram=1,
+        siglen=200,
+        repeatable=False,
+    ):
+        """ Specific parameters of the MinHashingBlocking:
+
+        :param kwordsgram: is the length of the k-wordgrams used
+            (the lower k is, the faster is the training)
+        :param siglen: the length of the sentences signature
+        :param repeatable: whether a fixed random seed should be used or not.
+            Using a fixed random seed allows to have repeatable results.
+        """
+
         super(MinHashingBlocking, self).__init__(ref_attr_index, target_attr_index)
         self.threshold = threshold
         self.kwordsgram = kwordsgram
         self.siglen = siglen
-        self.minhasher = Minlsh()
+        self._repeatable = repeatable
+        self.minhasher = self._get_new_minhasher()
         self.nb_elements = None
 
+    def _get_new_minhasher(self):
+        if self._repeatable:
+            return Minlsh(random_seed=self.FIXED_RANDOM_SEED)
+        return Minlsh()
+
     def _fit(self, refset, targetset):
         """ Find the blocking using minhashing
         """
@@ -629,7 +653,7 @@ class MinHashingBlocking(BaseBlocking):
     def _cleanup(self):
         """ Cleanup blocking for further use (e.g. in pipeline)
         """
-        self.minhasher = Minlsh()
+        self.minhasher = self._get_new_minhasher()
         self.nb_elements = None
 
 
