@@ -15,16 +15,13 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from os.path import exists as fileexists
-from os import path as osp
 import codecs
 import json
 import csv
-
-from six import binary_type, string_types, iteritems
-from six.moves import xrange
-from six.moves.urllib.request import urlopen
-import six.moves.urllib as urllib
+import urllib
+from urllib.request import urlopen
+from os.path import exists as fileexists
+from os import path as osp
 
 from lxml import etree
 
@@ -50,7 +47,7 @@ def autocast(data, encoding=None):
             return float(data.replace(",", "."))
         except ValueError:
             data = data.strip()
-            if encoding and isinstance(data, binary_type):
+            if encoding and isinstance(data, bytes):
                 return data.decode(encoding)
             return data
 
@@ -181,7 +178,7 @@ def sparqljson(endpoint, query, lang_order=("fr", "en"), raise_on_error=False, a
     results = rawresults["results"]["bindings"]
     data_lang = {}
     for row in results:
-        for k, v in iteritems(row):
+        for k, v in row.items():
             if v["type"] == "uri":
                 # Uri, keep it in a set
                 data.setdefault(k, set()).add(v["value"])
@@ -195,7 +192,7 @@ def sparqljson(endpoint, query, lang_order=("fr", "en"), raise_on_error=False, a
     def keyfunc(x):
         return lang_order.index(x[1]) if x[1] in lang_order else len(lang_order)
 
-    data.update(dict([(k, sorted(v, key=keyfunc)[0][0]) for k, v in iteritems(data_lang)]))
+    data.update(dict([(k, sorted(v, key=keyfunc)[0][0]) for k, v in data_lang.items()]))
     return data
 
 
@@ -242,7 +239,7 @@ def parsefile(
         if field_size_limit:
             csv.field_size_limit(field_size_limit)
 
-        if isinstance(filename, string_types):
+        if isinstance(filename, str):
             csvfile = open(filename, "r")
         else:
             csvfile = filename
@@ -299,16 +296,7 @@ def write_results(matched, alignset, targetset, resultfile):
             for target, dist in matched[aligned]:
                 alignid = alignset[aligned][0]
                 targetid = targetset[target][0]
-                fobj.write(
-                    "%s;%s;%s\n"
-                    % (
-                        alignid.encode("utf-8") if isinstance(alignid, string_types) else alignid,
-                        targetid.encode("utf-8")
-                        if isinstance(targetid, string_types)
-                        else targetid,
-                        dist,
-                    )
-                )
+                fobj.write("%s;%s;%s\n" % (alignid, targetid, dist,))
 
 
 def split_file(filename, outputdir, nblines=60000):
@@ -340,7 +328,7 @@ def split_file(filename, outputdir, nblines=60000):
             outfile.write(line)
         outfile.close()
         count += 1
-    return list(map(str, xrange(count)))
+    return list(map(str, range(count)))
 
 
 ###############################################################################
@@ -351,7 +339,7 @@ class AbstractPrettyPrint(object):
     """
 
     def pprint_text(self, text, named_entities, **kwargs):
-        newtext = u""
+        newtext = ""
         indice = 0
         tindices = dict([(t.start, (uri, t)) for uri, p, t in named_entities])
         while indice < len(text):
@@ -385,7 +373,7 @@ class HTMLPrettyPrint(AbstractPrettyPrint):
     def pprint_entity(self, uri, word, **kwargs):
         """ Pretty print an entity """
         klass = ' class="%s"' % kwargs["html_class"] if "html_class" in kwargs else ""
-        return u'<a href="%s"%s>%s</a>' % (uri, klass, word)
+        return '<a href="%s"%s>%s</a>' % (uri, klass, word)
 
 
 class ValidXHTMLPrettyPrint(HTMLPrettyPrint):
@@ -405,7 +393,7 @@ class ValidXHTMLPrettyPrint(HTMLPrettyPrint):
 </html>"""  # noqa
 
     def is_valid(self, html):
-        if isinstance(html, string_types):
+        if isinstance(html, str):
             html = html.encode("utf-8")
         try:
             etree.fromstring(
