@@ -14,12 +14,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
-from __future__ import print_function
-
-from six import itervalues
-from six.moves import cPickle, xrange
-
-from random import randint
+import pickle
+import random
 from collections import defaultdict
 
 import numpy as np
@@ -29,10 +25,13 @@ from scipy.optimize import bisect
 ###############################################################################
 # UTILITY FUNCTIONS ###########################################################
 ###############################################################################
-def randomhashfunction(zr):
+def randomhashfunction(zr, randint=random.randint):
     """ Return a random hash function, mapping x in Z to ZR
         h:x -> ax + b mod R
 
+        :param randint_function: a function that returns a random integer
+        in range [a, b], including both end points. If this function is not
+        given, the randint function from the standard random module is used.
     """
     bound = max(zr - 1, 1)
     a = randint(1, bound)
@@ -70,7 +69,7 @@ class Minlsh(object):
     """ Operate minhashing + locally-sensitive-hashing to find similar sentences
     """
 
-    def __init__(self, tokenizer_func=None, verbose=False):
+    def __init__(self, tokenizer_func=None, random_seed=None, verbose=False):
         """ Initialize a minhashing/lsh object
 
         Parameters:
@@ -79,11 +78,16 @@ class Minlsh(object):
            * tokenizer_func is a function that take the sentences
              as argument and return the rows of the sparse matrix
              of tokens, and its shape.
+           * random_seed is an *optional* parameter that can be used to control
+             the random seed of hashing functions. Controlling the seed allows
+             to re-use the same hash functions, and which enables repeatable
+             results.
 
            * verbose is a boolean that trigger the display of
              some informations
         """
         self._trained = False
+        self._random_seed = random_seed
         self.sigmatrix = None
         if tokenizer_func:
             # Use given tokenizer_func
@@ -108,7 +112,7 @@ class Minlsh(object):
         """ Generator of k-wordgrams on the given sentence
         """
         words = sentence.split(" ")
-        for r in xrange(len(words)):
+        for r in range(len(words)):
             for width in range(1, k + 1):
                 if r + width <= len(words):
                     yield " ".join(words[r : r + width])
@@ -147,10 +151,11 @@ class Minlsh(object):
         nrows, ncols = shape
         sig = np.empty((siglen, nrows))
         # Generate the random hash functions
-        hashfunc = [randomhashfunction(ncols) for _ in xrange(siglen)]
+        minlsh_random = random.Random(self._random_seed)
+        hashfunc = [randomhashfunction(ncols, randint=minlsh_random.randint) for _ in range(siglen)]
         # Compute hashing values just for once.
         # Avoid multiple recomputations for the same column.
-        hashvalues = np.array([[hashfunc[i](r) for r in xrange(ncols)] for i in xrange(siglen)])
+        hashvalues = np.array([[hashfunc[i](r) for r in range(ncols)] for i in range(siglen)])
 
         docind = 0
         while rows:
@@ -172,14 +177,14 @@ class Minlsh(object):
             return
 
         with open(savefile, "wb") as fobj:
-            pickler = cPickle.Pickler(fobj)
+            pickler = pickle.Pickler(fobj)
             pickler.dump(self.sigmatrix)
 
     def load(self, savefile):
         """ Load a trained minhashing """
 
         with open(savefile, "rb") as fobj:
-            pickler = cPickle.Unpickler(fobj)
+            pickler = pickle.Unpickler(fobj)
             self.sigmatrix = pickler.load()
 
         if self.sigmatrix is not None:
@@ -220,9 +225,9 @@ class Minlsh(object):
 
         buckets = defaultdict(set)
         similars = set()
-        for r in xrange(0, sig.shape[0], bandsize):
+        for r in range(0, sig.shape[0], bandsize):
             buckets.clear()
-            for i in xrange(sig.shape[1]):
+            for i in range(sig.shape[1]):
                 buckets[tuple(sig[r : r + bandsize, i])].add(i)
-            similars.update(set(tuple(v) for v in itervalues(buckets) if len(v) >= minclustersize))
+            similars.update(set(tuple(v) for v in buckets.values() if len(v) >= minclustersize))
         return similars
