@@ -16,22 +16,16 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
-import sys
-import six
-
-if sys.version_info >= (2, 7):
-    import unittest
-else:
-    import unittest2 as unittest
+import unittest
 import random
 
-random.seed(6)  # Make sure tests are repeatable
 from os import path
 
 import numpy as np
 
-from nazca.utils.normalize import simplify
+# Make sure tests are repeatable
+random.seed(6)  # noqa
+
 import nazca.rl.aligner as alig
 import nazca.rl.blocking as blo
 from nazca.utils.distances import LevenshteinProcessing, GeographicalProcessing
@@ -58,7 +52,7 @@ class AlignerTestCase(unittest.TestCase):
         aligner = alig.BaseAligner(threshold=30, processings=processings)
         mat, matched = aligner.align(refset, targetset)
         true_matched = [(0, 0), (0, 2), (1, 2), (3, 1)]
-        for k, values in six.iteritems(matched):
+        for k, values in matched.items():
             for v, distance in values:
                 self.assertIn((k, v), true_matched)
 
@@ -134,7 +128,7 @@ class AlignerTestCase(unittest.TestCase):
         predict_matched = set()
         for alignind, targetind in blocking.iter_indice_blocks():
             mat, matched = aligner._get_match(refset, targetset, alignind, targetind)
-            for k, values in six.iteritems(matched):
+            for k, values in matched.items():
                 for v, distance in values:
                     predict_matched.add((k, v))
         self.assertEqual(true_matched, predict_matched)
@@ -160,7 +154,7 @@ class AlignerTestCase(unittest.TestCase):
         )
         global_mat, global_matched = aligner.align(refset, targetset)
         predict_matched = set()
-        for k, values in six.iteritems(global_matched):
+        for k, values in global_matched.items():
             for v, distance in values:
                 predict_matched.add((k, v))
         self.assertEqual(true_matched, predict_matched)
@@ -253,6 +247,10 @@ class PipelineAlignerTestCase(unittest.TestCase):
         for m in uniq_matched:
             self.assertIn(m, matched_wo_distance)
 
+        expected_distances = [1.00000, 4.5532517, 11.396689, 15.692410]
+        for index, (_, _, distance) in enumerate(sorted(matched, key=lambda x: x[2])):
+            self.assertAlmostEqual(distance, expected_distances[index], 6)
+
 
 if __name__ == "__main__":
     unittest.main()
