@@ -16,27 +16,15 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
-import sys
-
-if sys.version_info >= (2, 7):
-    import unittest
-else:
-    import unittest2 as unittest
+import unittest
 from os import path
 from functools import partial
 import random
 
-random.seed(6)  # Make sure tests are repeatable / Minhashing
+# Make sure tests are repeatable / Minhashing
+random.seed(6)  # noqa
 
-from nazca.utils.distances import (
-    levenshtein,
-    soundex,
-    soundexcode,
-    jaccard,
-    euclidean,
-    geographical,
-)
+from nazca.utils.distances import soundexcode
 from nazca.rl.blocking import (
     KeyBlocking,
     SortedNeighborhoodBlocking,
@@ -350,16 +338,16 @@ class KmeansBlockingTest(unittest.TestCase):
 class MinHashingBlockingTest(unittest.TestCase):
     def test_minhashing(self):
         refset = [
-            ["V1", "label1", u"Un nuage flotta dans le grand ciel bleu."],
-            ["V2", "label2", u"Pour quelle occasion vous êtes-vous apprêtée ?"],
-            ["V3", "label3", u"Je les vis ensemble à plusieurs occasions."],
-            ["V4", "label4", u"Je n'aime pas ce genre de bandes dessinées tristes."],
-            ["V5", "label5", u"Ensemble et à plusieurs occasions, je les vis."],
+            ["V1", "label1", "Un nuage flotta dans le grand ciel bleu."],
+            ["V2", "label2", "Pour quelle occasion vous êtes-vous apprêtée ?"],
+            ["V3", "label3", "Je les vis ensemble à plusieurs occasions."],
+            ["V4", "label4", "Je n'aime pas ce genre de bandes dessinées tristes."],
+            ["V5", "label5", "Ensemble et à plusieurs occasions, je les vis."],
         ]
         targetset = [
-            ["T1", "labelt1", u"Des grands nuages noirs flottent dans le ciel."],
-            ["T2", "labelt2", u"Je les ai vus ensemble à plusieurs occasions."],
-            ["T3", "labelt3", u"J'aime les bandes dessinées de genre comiques."],
+            ["T1", "labelt1", "Des grands nuages noirs flottent dans le ciel."],
+            ["T2", "labelt2", "Je les ai vus ensemble à plusieurs occasions."],
+            ["T3", "labelt3", "J'aime les bandes dessinées de genre comiques."],
         ]
         normalizer = SimplifyNormalizer(attr_index=2, lemmas=FRENCH_LEMMAS)
         refset = normalizer.normalize_dataset(refset)
