@@ -16,13 +16,7 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
-import sys
-
-if sys.version_info >= (2, 7):
-    import unittest
-else:
-    import unittest2 as unittest
+import unittest
 import shutil
 from contextlib import contextmanager
 from os import path
@@ -69,7 +63,7 @@ class ValidXHTMLPrettyPrintTest(unittest.TestCase):
         if int(etree.__version__ < "3.2.0"):
             # https://bugs.launchpad.net/lxml/+bug/673205
             self.skipTest("Lxml version to old for ValidXHTMLPrettyPrint")
-        self.assertTrue(ValidXHTMLPrettyPrint().is_valid(u"<p>coucou</p>"))
+        self.assertTrue(ValidXHTMLPrettyPrint().is_valid("<p>coucou</p>"))
 
     @pytest.mark.xfail(reason="lxml seems unable to load the remote DTD")
     def test_valid_unicode(self):
@@ -78,7 +72,7 @@ class ValidXHTMLPrettyPrintTest(unittest.TestCase):
         if int(etree.__version__ < "3.2.0"):
             # https://bugs.launchpad.net/lxml/+bug/673205
             self.skipTest("Lxml version to old for ValidXHTMLPrettyPrint")
-        self.assertTrue(ValidXHTMLPrettyPrint().is_valid(u"<p>hé</p>"))
+        self.assertTrue(ValidXHTMLPrettyPrint().is_valid("<p>hé</p>"))
 
     @pytest.mark.xfail(reason="lxml seems unable to load the remote DTD")
     def test_invalid(self):
@@ -87,7 +81,7 @@ class ValidXHTMLPrettyPrintTest(unittest.TestCase):
         if int(etree.__version__ < "3.2.0"):
             # https://bugs.launchpad.net/lxml/+bug/673205
             self.skipTest("Lxml version to old for ValidXHTMLPrettyPrint")
-        self.assertFalse(ValidXHTMLPrettyPrint().is_valid(u"<p><div>coucou</div></p>"))
+        self.assertFalse(ValidXHTMLPrettyPrint().is_valid("<p><div>coucou</div></p>"))
 
     @unittest.skipUnless(NLTK_AVAILABLE, "nltk is not available")
     def test_prettyprint(self):
@@ -101,9 +95,9 @@ class ValidXHTMLPrettyPrintTest(unittest.TestCase):
         self.assertEqual(
             html,
             (
-                u'Hello <a href="http://example.com/everyone">everyone</a>, '
-                u'this is   <a href="http://example.com/me">me</a> speaking. '
-                u'And <a href="http://example.com/me">me</a>.'
+                'Hello <a href="http://example.com/everyone">everyone</a>, '
+                'this is   <a href="http://example.com/me">me</a> speaking. '
+                'And <a href="http://example.com/me">me</a>.'
             ),
         )
 
@@ -119,9 +113,9 @@ class ValidXHTMLPrettyPrintTest(unittest.TestCase):
         self.assertEqual(
             html,
             (
-                u'Hello <a href="http://example.com/everyone" class="ner">everyone</a>, '
-                u'this is   <a href="http://example.com/me" class="ner">me</a> speaking. '
-                u'And <a href="http://example.com/me" class="ner">me</a>.'
+                'Hello <a href="http://example.com/everyone" class="ner">everyone</a>, '
+                'this is   <a href="http://example.com/me" class="ner">me</a> speaking. '
+                'And <a href="http://example.com/me" class="ner">me</a>.'
             ),
         )
 
@@ -131,9 +125,9 @@ class DataIOTestCase(unittest.TestCase):
         data = parsefile(path.join(TESTDIR, "data", "file2parse"), [0, (2, 3), 4, 1], delimiter=",")
         self.assertEqual(
             [
-                [1, (12, 19), u"apple", u"house"],
-                [2, (21.9, 19), u"stramberry", u"horse"],
-                [3, (23, 2.17), u"cherry", u"flower"],
+                [1, (12, 19), "apple", "house"],
+                [2, (21.9, 19), "stramberry", "horse"],
+                [3, (23, 2.17), "cherry", "flower"],
             ],
             data,
         )
@@ -146,9 +140,9 @@ class DataIOTestCase(unittest.TestCase):
         )
         self.assertEqual(
             [
-                [1, ("12", 19), u"apple", u"house"],
-                [2, ("21.9", 19), u"stramberry", u"horse"],
-                [3, ("23", 2.17), u"cherry", u"flower"],
+                [1, ("12", 19), "apple", "house"],
+                [2, ("21.9", 19), "stramberry", "horse"],
+                [3, ("23", 2.17), "cherry", "flower"],
             ],
             data,
         )
@@ -174,8 +168,8 @@ class DataIOTestCase(unittest.TestCase):
         self.assertEqual(autocast("1,"), 1.0)
         self.assertEqual(autocast("1,2"), 1.2)
         self.assertEqual(autocast("1,2X"), "1,2X")
-        self.assertEqual(autocast(u"tété"), u"tété")
-        self.assertEqual(autocast("tété", encoding="utf-8"), u"tété")
+        self.assertEqual(autocast("tété"), "tété")
+        self.assertEqual(autocast("tété", encoding="utf-8"), "tété")
 
     def test_split_file(self):
         NBLINES = 190
@@ -252,7 +246,9 @@ class DataIOTestCase(unittest.TestCase):
                             },
                             "uri": {
                                 "type": "uri",
-                                "value": "http://dbpedia.org/resource/Python_(programming_language)",
+                                "value": (
+                                    "http://dbpedia.org/resource/" "Python_(programming_language)"
+                                ),
                             },
                         },
                         {
@@ -275,8 +271,8 @@ class DataIOTestCase(unittest.TestCase):
     @unittest.skipUnless(SPARQL_ENABLED, "python-sparqlwrapper is not installed")
     def test_sparql_execute_no_raise_on_error(self):
         rawresults = _sparqlexecute(
-            u"http://dbpedia.org/sparql",
-            u"""SELECT DISTINCT ?uri
+            "http://dbpedia.org/sparql",
+            """SELECT DISTINCT ?uri
                                     WHERE{
                                     ?uri faultyrdf
                                     ?uri rdf:type ?type}""",
@@ -286,9 +282,9 @@ class DataIOTestCase(unittest.TestCase):
     @unittest.skipUnless(SPARQL_ENABLED, "python-sparqlwrapper is not installed")
     def test_sparql_execute_raise_on_error(self):
         with self.assertRaises(RuntimeError):
-            rawresults = _sparqlexecute(
-                u"http://dbpedia.org/sparql",
-                u"""SELECT DISTINCT ?uri
+            _sparqlexecute(
+                "http://dbpedia.org/sparql",
+                """SELECT DISTINCT ?uri
                                         WHERE{
                                         ?uri faultyrdf
                                         ?uri rdf:type ?type}""",
