@@ -16,19 +16,13 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
-import sys
-from six.moves import range
-
-if sys.version_info >= (2, 7):
-    import unittest
-else:
-    import unittest2 as unittest
+import unittest
 import random
-
-random.seed(6)  # Make sure tests are repeatable
 from dateutil import parser as dateparser
 
+# Make sure tests are repeatable
+random.seed(6)  # noqa
+
 from nazca.utils.distances import (
     levenshtein,
     soundex,
@@ -100,7 +94,7 @@ class DistancesTest(unittest.TestCase):
 
         self.assertEqual(jaccard("bonjour", "bonjour"), 0.0)
         self.assertAlmostEqual(jaccard("boujour", "bonjour"), 1, 2)
-        self.assertAlmostEqual(jaccard(u"sacré rubert", u"sacré hubert"), 0.667, 2)
+        self.assertAlmostEqual(jaccard("sacré rubert", "sacré hubert"), 0.667, 2)
 
         # Test symetry
         self.assertEqual(jaccard("orange", "morange"), jaccard("morange", "orange"))
@@ -198,8 +192,8 @@ class ExactMatchTestCase(unittest.TestCase):
 
 class LevenshteinTestCase(unittest.TestCase):
     def setUp(self):
-        self.input1 = [u"Victor Hugo", u"Albert Camus", "Jean Valjean"]
-        self.input2 = [u"Victor Wugo", u"Albert Camus", "Albert Camu"]
+        self.input1 = ["Victor Hugo", "Albert Camus", "Jean Valjean"]
+        self.input2 = ["Victor Wugo", "Albert Camus", "Albert Camu"]
         self.distance = levenshtein
         processing = LevenshteinProcessing()
         self.matrix = processing.cdist(self.input1, self.input2)
@@ -220,8 +214,7 @@ class LevenshteinTestCase(unittest.TestCase):
         self.assertTrue(((m + 10 * m - m * 3) == (8 * m)).all())
 
     def test_pdist(self):
-        _input = [u"Victor Wugo", u"Albert Camus", "Albert Camu"]
-        d = self.distance
+        _input = ["Victor Wugo", "Albert Camus", "Albert Camu"]
         processing = LevenshteinProcessing()
         pdist = processing.pdist(_input)
         self.assertEqual([6, 6, 1], pdist)
@@ -230,7 +223,7 @@ class LevenshteinTestCase(unittest.TestCase):
 class SoundexTestCase(unittest.TestCase):
     def test_pdist(self):
         processing = SoundexProcessing()
-        _input = [u"Robert Ugo", u"Rubert Ugo", "Rubert Pugo"]
+        _input = ["Robert Ugo", "Rubert Ugo", "Rubert Pugo"]
         pdist = processing.pdist(_input)
         self.assertEqual([0, 1, 1], pdist)
 
@@ -238,7 +231,7 @@ class SoundexTestCase(unittest.TestCase):
 class JaccardTestCase(unittest.TestCase):
     def test_pdist(self):
         processing = JaccardProcessing()
-        _input = [u"Robert Ugo", u"Rubert Ugo", "Rubert Pugo"]
+        _input = ["Robert Ugo", "Rubert Ugo", "Rubert Pugo"]
         pdist = processing.pdist(_input)
         results = [0.666, 1, 0.666]
         for ind, value in enumerate(pdist):
@@ -248,7 +241,7 @@ class JaccardTestCase(unittest.TestCase):
 class DifflibTestCase(unittest.TestCase):
     def test_pdist(self):
         processing = DifflibProcessing()
-        _input = [u"Robert Ugo", u"Rubert Ugo", "Rubert Pugo"]
+        _input = ["Robert Ugo", "Rubert Ugo", "Rubert Pugo"]
         pdist = processing.pdist(_input)
         results = [0.099, 0.238, 0.14]
         for ind, value in enumerate(pdist):
